
CRUD App with FastAPI
=====================

This is a fully functional minimal CRUD app with API:

.. literalinclude :: fastapi.py
    :language: python

Read more about FastAPI: `FastAPI docs <https://fastapi.tiangolo.com/>`_